package com.younike.system.service;

import com.younike.common.core.domain.AjaxResult;
import com.younike.system.domain.Member;
import com.younike.system.domain.vo.MemberVo;
import com.younike.system.param.MemberQueryParam;
import com.younike.system.param.UserLoginParam;

import java.util.List;

/**
 * 会员Service接口
 * 
 * @author zulu.chen
 * @date 2022-01-04
 */
public interface IMemberService 
{
    /**
     * 用户登录接口
     * @param param
     * @return
     */
    AjaxResult login(UserLoginParam param);

    /**
     * 用户一键登录接口
     * @param param
     * @return
     */
    AjaxResult tokenLogin(UserLoginParam param);

    /**
     * 查询会员
     * 
     * @param memberId 会员主键
     * @return 会员
     */
    public Member selectMemberByMemberId(Long memberId);

    /**
     * 查询会员列表
     * 
     * @param member 会员
     * @return 会员集合
     */
    public List<Member> selectMemberList(Member member);

    /**
     * 查询会员列表
     *
     * @param member 会员
     * @return 会员集合
     */
    public List<MemberVo> pageList(MemberQueryParam member);

    /**
     * 新增会员
     * 
     * @param member 会员
     * @return 结果
     */
    public int insertMember(Member member);

    /**
     * 修改会员
     * 
     * @param member 会员
     * @return 结果
     */
    public int updateMember(Member member);

    /**
     * 批量删除会员
     * 
     * @param memberIds 需要删除的会员主键集合
     * @return 结果
     */
    public int deleteMemberByMemberIds(Long[] memberIds);

    /**
     * 删除会员信息
     * 
     * @param memberId 会员主键
     * @return 结果
     */
    public int deleteMemberByMemberId(Long memberId);

    /**
     * 通过手机号查询会员信息
     *
     * @param phone
     * @return
     */
    Member getMemberByPhone(String phone);

    /**
     * 发送短信验证码
     *
     * @param phone
     * @return
     */
    AjaxResult sendCode(String phone);
}
